from flask_login import LoginManager, UserMixin
from werkzeug.security import generate_password_hash, check_password_hash
from .extensions import db, bcrypt
from datetime import datetime

login_manager = LoginManager()
login_manager.login_view = "auth.login"


class User(db.Model, UserMixin):
    __tablename__ = "users"

    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(64), unique=True, nullable=False)
    email = db.Column(db.String(120), unique=True, nullable=False)
    password_hash = db.Column(db.String(128))
    is_admin = db.Column(db.Boolean, default=False)
    created_at = db.Column(db.DateTime, default=datetime.utcnow)
    last_seen = db.Column(db.DateTime, default=datetime.utcnow)
    
    # User's assets
    locations = db.relationship("Location", backref="owner", lazy=True, cascade="all, delete-orphan")
    subnets = db.relationship("Subnet", backref="owner", lazy=True, cascade="all, delete-orphan")
    servers = db.relationship("Server", backref="owner", lazy=True, cascade="all, delete-orphan")
    apps = db.relationship("App", backref="owner", lazy=True, cascade="all, delete-orphan")

    def __repr__(self):
        return f"<User {self.username}>"

    def set_password(self, password):
        self.password_hash = generate_password_hash(password)

    def check_password(self, password):
        return check_password_hash(self.password_hash, password)

    def get_id(self):
        return str(self.id)


@login_manager.user_loader
def load_user(user_id):
    return User.query.get(int(user_id))
